@@ -4,24 +4,23 @@
 #' You are not likely to use this function, because \code{\link{iotable_get}} will
 #' call this function if necessary and properly filter out an input-output table.
 #' The only parameter is the Eurostat code of the table: 
-#' Symmetric input-output table - current prices (NACE Rev. 2) [naio_cp17_r2]
 #' Symmetric input-output table at basic prices (product by product) (naio_10_cp1700)	
 #' Symmetric input-output table at basic prices (industry by industry) (naio_10_cp1750)
 #' Symmetric input-output table at basic prices (product by product) (previous years prices) (naio_10_pyp1700)
 #' Symmetric input-output table at basic prices (industry by industry) (previous years prices) (naio_10_pyp1750)
+#' Table of trade and transport margins at basic prices (naio_10_cp1620) and 
+#' at previous' years prices (naio_10_pyp1620)
+#' Table of taxes less subsidies on products at basic prices (naio_10_cp1630)	and
+#' at previous' years prices (naio_10_pyp1630)
 #' 
-#' EU-level tables
-#' Input-output table for domestic output at current prices, 60 branches - EU aggregates (NACE Rev. 2) (naio_18_agg_60_r2)
-#' Input-output table at current prices, 10 branches - EU aggregates (NACE Rev. 2) (naio_17_agg_10_r2)
-#' Input-output table at current prices, 6 branches - EU aggregates (naio_17_agg_6)	 
-#' 
-#' At the moment import and domestic tables are not yet supported in the package.
-#' The data is downloaded in the tempdir() under the name the statistical product as an
-#' rds file. (For example: naio_10_cp1750.rds)
+#' The data is downloaded in the \code{tempdir()}under the name the statistical product as an
+#' rds file. (For example: \code{naio_10_cp1750.rds})
 #' The temporary directory is emptied at every normal R session exit.
-#' @param source Currently only source = "eurostat" works. Later OECD Stan will be added.
-#' @param stk_flow Defaults to "TOTAL". Possible values are "DOM", "IMP", "TOTAL". In tables
-#' where no distinction is made it is not needed.
+#' @param source Currently only source = \code{eurostat} works. Later OECD Stan will be added.
+#' @param data_directory Defaults to \code{NULL}, if a valid directory, it will try to save the pre-processed 
+#' data file here with labelling. 
+#' @param force_download Defaults to \code{TRUE}. If \code{FALSE} it will use the existing downloaded file
+#' in the \code{data_directory} or the temporary directory, if it exists.
 #' @importFrom magrittr %>%
 #' @importFrom dplyr filter select mutate left_join rename
 #' @importFrom eurostat get_eurostat label_eurostat
@@ -32,42 +31,48 @@
 #'  }
 #' @export
 
-iotables_download <- function ( source = "naio_cp17_r2", 
-                                stk_flow = "DOM" ) {
-  t_cols2_lab = NULL; t_rows2_lab = NULL; values_lab = NULL
-  . = NULL; downloaded <- NULL; downloaded_labelled <- NULL
+iotables_download <- function ( source = "naio_10_cp1700", 
+                                data_directory = NULL,
+                                force_download = TRUE ) {
+  t_cols2_lab <- t_rows2_lab <- values_lab <- stk_flow <- NULL
+  . <- downloaded <- downloaded_labelled <- NULL
 
-  possible_sources_60 <- c( "naio_cp17_r2", "naio_10_cp1700", "naio_10_cp1750", 
-                         "naio_10_pyp1700", "naio_10_pyp1750", 
-                         "naio_17_agg_60_r2", "naio_18_agg_60_r2", 
-                         "naio_19_agg_60_r2")
+  possible_download_sources <- c( "naio_10_cp1700", "naio_10_cp1750", 
+                         "naio_10_pyp1700", "naio_10_pyp1750",
+                         "naio_10_cp1620", "naio_10_pyp1620", 
+                         "naio_10_cp1630", "naio_10_pyp1630" )
   source <- tolower (source)
-  if ( ! source %in%  possible_sources_60 ) {
-    supported_tables <- paste( possible_sources_60, collapse = ", ")
+  if ( ! source %in%  possible_download_sources ) {
+    supported_tables <- paste( possible_download_sources, collapse = ", ")
     stop (source, " is not in supported tables [", supported_tables, "]") 
   }
   
   retrieve_from_temp_bulk <-paste0(tempdir(),
      "\\eurostat/", source, "_date_code_TF.rds" )
-
+ 
+  #downloaded <- readRDS("C:/Users/Daniel Antal/OneDrive - Visegrad Investments/2017 Projektek/iotables/data-raw/naio_cp17_r2.rds")
   #only download the Eurostat bulk file if necessary.
-  if ( source == "naio_cp17_r2") {
-    downloaded <- readRDS("C:/Users/Daniel Antal/OneDrive - Visegrad Investments/2017 Projektek/iotables/data-raw/naio_cp17_r2.rds")
-    } else {
-    if(!file.exists(retrieve_from_temp_bulk)){
+  
+  if ( !is.null (data_directory)   ) {
+    save_file_name <- paste0(data_directory, "/", source, ".rds")
+    if ( ! force_download && file.exists(save_file_name) )
+      return(readRDS(save_file_name))
+  }
+  
+  if (!file.exists(retrieve_from_temp_bulk) | force_download == TRUE){
       downloaded <- tryCatch(eurostat::get_eurostat (source),
                              error=function(e) message ("No data was found with this identifier."))
     } else {
-      warning ('The bulk Eurostat file is retrieved from the temporary directory.')
+      message ('The bulk Eurostat file is retrieved from the temporary directory.')
       downloaded <- readRDS( retrieve_from_temp_bulk )
     }
-  }
+
   
   
   #label the raw Eurostat file, add rename variables with _lab suffix
   downloaded_labelled <- downloaded  %>%
     eurostat::label_eurostat (., fix_duplicated = TRUE) %>%          #add meaningful labels to raw data
-    setNames( ., paste0( names (.), "_lab" ) )    %>%  
+    stats::setNames( ., paste0( names (.), "_lab" ) )    %>%  
     dplyr::mutate ( rows = 1:nrow(.) ) %>%  #because long and wide formats are not symmetric
     dplyr::rename ( values = values_lab ) 
   
@@ -76,12 +81,12 @@ iotables_download <- function ( source = "naio_cp17_r2",
   downloaded <- downloaded  %>%
     dplyr::mutate ( rows = 1:nrow(.)) %>%
     dplyr::left_join (., downloaded_labelled, by = c("rows", "values")) 
-  message ("Joined labelled and not labelled data.")
+  #message ("Joined labelled and not labelled data.")
   
   if ( "stk_flow" %in% names ( downloaded )) {
     downloaded <- downloaded %>%
       dplyr::filter ( stk_flow == stk_flow )
-    message ("Type " , stk_flow, " is returned.")
+    #message ("Type " , stk_flow, " is returned.")
   }
   
   if ( source == "naio_cp17_r2" ){
@@ -114,7 +119,15 @@ iotables_download <- function ( source = "naio_cp17_r2",
              "CPA_J62_63", "CPA_M69_70", "CPA_Q87_88", 
              "CPA_M74_75", "CPA_O", "CPA_P", "CPA_D")
     )
+  } #end of _r2 
+  
+  if( !is.null(data_directory) ) {
+    
+    save_file_name <- file.path(data_directory, paste0(source, ".rds"))
+    saveRDS( downloaded, file = save_file_name )
+    message ( "Saved the raw data of this table tpye in ",
+               save_file_name, "." )
   }
   
-   return( downloaded )
+  downloaded
 }
